0.9.9 API documentation: Core features

| 0.9.9 API documentation

- Main Page
- Modules
- Files

Modules | Typedefs
Core features

Features that implement in C++ the GLSL specification as closely as possible. More...

## Modules
| Common functions
| Provides GLSL common functions.
| Exponential functions
| Provides GLSL exponential functions.
| Geometric functions
| These operate on vectors as vectors, not component-wise.
| Vector types
| Vector types of two to four components with an exhaustive set of operators.
| Vector types with precision qualifiers
| Vector types with precision qualifiers which may result in various precision in term of ULPs.
| Matrix types
| Matrix types of with C columns and R rows where C and R are values between 2 to 4 included.
| Matrix types with precision qualifiers
| Matrix types with precision qualifiers which may result in various precision in term of ULPs.
| Integer functions
| Provides GLSL functions on integer types.
| Matrix functions
| Provides GLSL matrix functions.
| Floating-Point Pack and Unpack Functions
| Provides GLSL functions to pack and unpack half, single and double-precision floating point values into more compact integer types.
| Angle and Trigonometry Functions
| Function parameters specified as angle are assumed to be in units of radians.
| Vector Relational Functions
| Relational and equality operators (<, <=, >, >=, ==, !=) are defined to operate on scalars and produce scalar Boolean results.

## Typedefs
typedef mat< 3, 2, float, defaultp > | mat3x2
| 3 columns of 2 components matrix of single-precision floating-point numbers. More...

## Detailed Description

Features that implement in C++ the GLSL specification as closely as possible.

The GLM core consists of C++ types that mirror GLSL types and C++ functions that mirror the GLSL functions.

The best documentation for GLM Core is the current GLSL specification, version 4.2 (pdf file).

GLM core functionalities require <glm/glm.hpp> to be included to be used.

## Typedef Documentation

typedef mat< 3, 2, f32, defaultp > mat3x2

3 columns of 2 components matrix of single-precision floating-point numbers.

See also
  GLSL 4.20.8 specification, section 4.1.6 Matrices

Definition at line 15 of file matrix_float3x2.hpp.